@echo off
REM ===========================================================================================
REM pdfa.cmd
REM Copyright 2013 by MCB Systems. 
REM Free for personal and commercial use.  No warranties.
REM ===========================================================================================
REM
REM Summary:
REM    Combine up to five PDF input documents into one PDF/A output document.
REM    Renames input files to .old.pdf, and puts output file in the same folder
REM    as the input file(s).  Optionally displays Bookmarks panel by default.
REM 
REM Parameters:
REM    %1:  Mandatory.  PDF file to convert.  Will be used for output file name.
REM    %2:  Optional.  PDF file to convert.  Will be combined into one output.
REM    %4:  Optional.  PDF file to convert.  Will be combined into one output.
REM    %4:  Optional.  PDF file to convert.  Will be combined into one output.
REM    %5:  Optional.  PDF file to convert.  Will be combined into one output.
REM
REM    Alternately, set the last paramater to "-sb" (show bookmarks) to load a file that 
REM    sets the Inital View of the PDF to show the Bookmarks (outline) panel.  This is only 
REM    useful if the input file already has bookmarks, and does not really make sense when 
REM    concatenating multiple files, as bookmarks from later files would point to incorrect 
REM    page numbers.
REM
REM Dependencies:
REM    gswin32c.exe           - Ghostscript command-line program. Update the first 
REM                             line below "set gs_path=", with the path where gswin32c.exe
REM                             is found.
REM    C:\GS_PDFA\PDFA_def.ps - PDF/A conversion info.  Includes additional dependency on
REM                             ICC color profile (e.g. C:\GS_PDFA\AdobeRGB1998.icc).
REM    C:\GS_PDFA\PDF_ShowBookmarksPanel.ps - Command to cause bookmarks panel to be displayed.
REM
REM ===========================================================================================
REM Change Log:
REM
REM 04/15/2013:  Initial batch file.
REM
REM 05/03/2013:  Fix to support spaces in file names.
REM ===========================================================================================

REM ===========================================================================================
REM Check for the Ghostscript executable
REM ===========================================================================================

REM Change the next line to the folder that contains gswin32c.exe. End the line with a backslash (\):
set gs_path=C:\Program Files (x86)\gs\gs9.07\bin\
REM On a 32-bit version of Windows, gswin32c.exe will probably be here:
REM set gs_path=C:\Program Files\gs\gs9.07\bin\

if not exist "%gs_path%gswin32c.exe" (
   echo "%gs_path%gswin32c.exe" not found. Exiting.
   goto End
)

REM ===========================================================================================
REM Check for parameters
REM ===========================================================================================

if ###%1###==###### goto NoParam
goto ParamsFound

:NoParam
echo.
echo Missing parameter(s)
echo.
echo Usage:  pdfa file1 [file2^|-sb] [file3^|-sb] [file4^|-sb] [file5^|-sb]
echo.
echo Do NOT specify the .pdf extension on the input parameters.
echo.
echo To set the Initial View of the PDF to show the Bookmarks (outline) panel,
echo set the last parameter to "-sb" (show bookmarks).  The input file must 
echo already contain bookmarks.  Not recommended when concatenating files.
echo.
echo Usage examples:
echo.
echo    1. If you have a credit card statement with two reconciliation 
echo       reports to attach, use the following command:
echo.
echo       pdfa CCstatement recon1 recon2
echo.
echo       Output:
echo           CCstatement.pdf
echo           CCstatement.old.pdf
echo           recon1.old.pdf
echo           recon2.old.pdf
echo.
echo    2. Convert a tax return that includes bookmarks:
echo.
echo       pdfa "Tax Return" -sb
echo.
echo       Output:
echo          Tax Return.pdf
echo          Tax Return.old.pdf
echo.
echo Delete the .old files if you are satisfied with the new PDF/A document.
echo.
goto End

:ParamsFound
REM Expand params and strip surrounding quotation marks, if any.
set file1=%~1
set file2=%~2
set file3=%~3
set file4=%~4
set file5=%~5

REM ===========================================================================================
REM Before renaming any files, check that all specified input files exist
REM ===========================================================================================

set ShowBookmarksPanel=N

REM First parameter always exists (checked above)
if not exist "%file1%.pdf" (
   echo "%file1%.pdf" not found. Exiting.
   goto End
)
REM If the next parameter doesn't exist, skip to renaming files.
if ###%2###==###### goto RenameFiles
REM If the next parameter is "-sb" (ShowBookmarks), skip to renaming files.
if "%file2%"=="-sb" goto ShowBookmarksAndRenameFiles
if not exist "%file2%.pdf" (
   echo "%file2%.pdf" not found. Exiting.
   goto End
)
if ###%3###==###### goto RenameFiles
if "%file3%"=="-sb" goto ShowBookmarksAndRenameFiles
if not exist "%file3%.pdf" (
   echo "%file3%.pdf" not found. Exiting.
   goto End
)
if ###%4###==###### goto RenameFiles
if "%file4%"=="-sb" goto ShowBookmarksAndRenameFiles
if not exist "%file4%.pdf" (
   echo "%file4%.pdf" not found. Exiting.
   goto End
)
if ###%5###==###### goto RenameFiles
if "%file5%"=="-sb" goto ShowBookmarksAndRenameFiles
if not exist "%file5%.pdf" (
   echo "%file5%.pdf" not found. Exiting.
   goto End
)

REM ===========================================================================================
REM Rename input file(s) to .old.pdf and build a list of input files.  
REM Optionlly set flag to show the Bookmarks panel
REM ===========================================================================================

:ShowBookmarksAndRenameFiles
set ShowBookmarksPanel=Y

:RenameFiles

REM First parameter always exists (checked above)
ren "%file1%.pdf" "%file1%.old.pdf"
set inputfilelist="%file1%.old.pdf"

REM If the next parameter doesn't exist, skip to converting files.
if ###%2###==###### goto ConvertFiles
REM If the next parameter is "-sb" (ShowBookmarks), skip to converting files.
if "%file2%"=="-sb" goto ConvertFiles
ren "%file2%.pdf" "%file2%.old.pdf"
set inputfilelist=%inputfilelist% "%file2%.old.pdf"

if ###%3###==###### goto ConvertFiles
if "%file3%"=="-sb" goto ConvertFiles
ren "%file3%.pdf" "%file3%.old.pdf"
set inputfilelist=%inputfilelist% "%file3%.old.pdf"

if ###%4###==###### goto ConvertFiles
if "%file4%"=="-sb" goto ConvertFiles
ren "%file4%.pdf" "%file4%.old.pdf"
set inputfilelist=%inputfilelist% "%file4%.old.pdf"

if ###%5###==###### goto ConvertFiles
if "%file5%"=="-sb" goto ConvertFiles
ren "%file5%.pdf" "%file5%.old.pdf"
set inputfilelist=%inputfilelist% "%file5%.old.pdf"

REM ===========================================================================================
REM Convert input file(s) to PDF/A.
REM ===========================================================================================

:ConvertFiles

REM If the last  parameter was "-sb" (ShowBookmarks), add the appropriate file to the file list
if %ShowBookmarksPanel%==Y (
   set inputfilelist=%inputfilelist% "C:\GS_PDFA\PDF_ShowBookmarksPanel.ps"
)

REM Convert to PDF/A. Use name of first input file as name of output file.
"%gs_path%\gswin32c" ^
   -dPDFA ^
   -dNOOUTERSAVE ^
   -sProcessColorModel=DeviceRGB ^
   -dUseCIEColor ^
   -sDEVICE=pdfwrite ^
   -o "%file1%.pdf" ^
   -dPDFACompatibilityPolicy=1 ^
    "C:\GS_PDFA\PDFA_def.ps" ^
    %inputfilelist%

REM ===========================================================================================
REM Open converted PDF/A file with the default PDF reader.
REM ===========================================================================================

REM The leading "title" (empty here) is necessary to get START to interpret parameters correctly
start "" /b %1.pdf

:End